@@ -32,7 +32,7 @@
 
 class KSerialWindow : public KTextEdit 
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	
 	public:
@@ -71,7 +71,7 @@ class KSerialWindow : public KTextEdit
 
 class KSerialView : public TQWidget
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
     	KSerialView( CPicoBlaze *cpu, TQWidget *parent );
